@@ -21,7 +21,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/// @file main.cpp
+/// @file src/main.cpp
 
 #include "parleymainwindow.h"
 #include <config-parley.h>
@@ -55,7 +55,7 @@ int main(int argc, char* argv[])
                                            "© 2004-2007\tPeter Hedlund\n"
                                            "© 2007-2010\tFrederik Gladhorn\n").toString() );
     aboutData.setOtherText( ki18n("Helps you train your vocabulary").toString() );
-    aboutData.setHomepage( QStringLiteral("http://edu.kde.org/parley") );
+    aboutData.setHomepage( QStringLiteral("https://edu.kde.org/parley") );
     aboutData.setBugAddress( "submit@bugs.kde.org");
 
     aboutData.addAuthor(ki18n("Inge Wallin").toString(),
@@ -115,8 +115,6 @@ int main(int argc, char* argv[])
     KCrash::initialize();
 
     QCommandLineParser parser;
-    parser.addVersionOption();
-    parser.addHelpOption();
     parser.addPositionalArgument(ki18n( "[file]" ).toString(), ki18n("Document file to open").toString() );
 
     aboutData.setupCommandLine(&parser);
